@@ -189,21 +189,25 @@ class AndroidElement(object):
 
     @property
     def info(self):
+        """获取元素信息"""
         logger.info(f'获取元素: {self._kwargs} 的所有信息')
         return self.get_element().info
 
     @property
     def text(self):
+        """获取元素文本属性"""
         logger.info(f'获取元素: {self._kwargs} 的文本')
         return self.get_element().info.get('text')
 
     @property
     def bounds(self):
+        """获取元素坐标"""
         logger.info(f'获取元素: {self._kwargs} 的坐标')
         return self.get_element().info.get('bounds')
 
     @property
     def rect(self):
+        """获取元素左上角的坐标以及宽高"""
         logger.info(f'获取元素: {self._kwargs} 左上角的坐标以及宽高')
         bounds = self.get_element().info.get('bounds')
         x = bounds['left']
@@ -214,45 +218,54 @@ class AndroidElement(object):
 
     @property
     def visibleBounds(self):
+        """获取元素可见坐标"""
         logger.info(f'获取元素: {self._kwargs} 的可见坐标')
         return self.get_element().info.get('visibleBounds')
 
     @property
     def focusable(self):
+        """获取元素是否聚焦"""
         logger.info(f'获取元素: {self._kwargs} 是否聚焦')
         return self.get_element().info.get('focusable')
 
     @property
     def selected(self):
+        """获取元素是否选中"""
         logger.info(f'获取元素: {self._kwargs} 是否选中')
         return self.get_element().info.get('selected')
 
     def child(self, *args, **kwargs):
-        """不能用于PageObject，会导致在应用启动前进行元素识别"""
+        """获取元素儿子节点，不能用于PageObject，会导致在应用启动前进行元素识别"""
         logger.info(f'获取元素 {self._kwargs},{self._index} 的子元素{kwargs}')
         return self.get_element().child(*args, **kwargs)
 
     def brother(self, *args, **kwargs):
+        """获取兄弟元素"""
         logger.info(f'获取元素 {self._kwargs},{self._index} 的兄弟元素{kwargs}')
         return self.get_element().sibling(*args, **kwargs)
 
     def left(self, *args, **kwargs):
+        """获取左边元素"""
         logger.info(f'获取元素 {self._kwargs} 左边的元素 {kwargs}')
         return self.get_element().left(*args, **kwargs)
 
     def right(self, *args, **kwargs):
+        """获取右边元素"""
         logger.info(f'获取元素 {self._kwargs} 右边的元素 {kwargs}')
         return self.get_element().right(*args, **kwargs)
 
     def up(self, *args, **kwargs):
+        """获取上边的元素"""
         logger.info(f'获取元素 {self._kwargs} 上边的元素 {kwargs}')
         return self.get_element().up(*args, **kwargs)
 
     def down(self, *args, **kwargs):
+        """获取下边的元素"""
         logger.info(f'获取元素 {self._kwargs} 下边的元素 {kwargs}')
         return self.get_element().down(*args, **kwargs)
 
     def exists(self, timeout=1):
+        """判断元素是否存在"""
         logger.info(f'判断元素是否存在: {self._kwargs},{self._index}')
         element = self.find_element(retry=0, timeout=timeout)
         if element is None:
@@ -289,51 +302,62 @@ class AndroidElement(object):
     #     logger.debug('点击成功')
 
     def click_exists(self, timeout=3):
+        """元素存在才点击"""
         logger.info(f'存在才点击元素: {self._kwargs},{self._index}')
         if self.exists(timeout=timeout):
             self.click()
 
     def click_gone(self):
+        """等元素消失后再点击"""
         logger.info(f'等元素 {self._kwargs} 消失后再点击')
         flag = self.get_element().click_gone()
         logger.info(flag)
         return flag
 
     def wait_gone(self, timeout=3):
+        """等待元素消失"""
         logger.info(f'等元素 {self._kwargs} 消失')
         flag = self.get_element().wait_gone(timeout=timeout)
         logger.info(flag)
         return flag
 
     def long_click(self):
+        """长按"""
         logger.info(f'长按元素 {self._kwargs}')
         self.get_element().long_click()
 
     def set_text(self, text):
+        """输入文本"""
         logger.info(f'输入文本: {text}')
         self.get_element().set_text(text)
 
     def clear_text(self):
+        """清除文本"""
         logger.info('清除文本')
         self.get_element().clear_text()
 
     def drag_to(self, *args, **kwargs):
+        """拖动到另外一个元素的位置"""
         logger.info(f'从当前元素{self._kwargs},{self._index}, 拖动到元素: {kwargs}')
         self.get_element().drag_to(*args, **kwargs)
 
     def swipe_left(self):
+        """向左滑动"""
         logger.info(f'往左滑动元素: {self._kwargs},{self._index}')
         self.get_element().swipe("left")
 
     def swipe_right(self):
+        """向右滑动"""
         logger.info(f'往右滑动元素: {self._kwargs},{self._index}')
         self.get_element().swipe("right")
 
     def swipe_up(self):
+        """向上滑动"""
         logger.info(f'往上滑动元素: {self._kwargs},{self._index}')
         self.get_element().swipe("up")
 
     def swipe_down(self):
+        """向下滑动"""
         logger.info(f'往下滑动元素: {self._kwargs},{self._index}')
         self.get_element().swipe("down")
 
