@@ -3,7 +3,6 @@
 # @File    : request.py
 import sys
 from urllib import parse
-
 import allure
 import requests
 import json as json_util
@@ -23,10 +22,17 @@ def request(func):
         except IndexError:
             path = kwargs.get("url", "")
 
+        args_new = args
         if "http" not in path:
             base_url = conf.get_item('common', 'base_url')
             if 'http' in base_url:
                 url = parse.urljoin(base_url, path)
+                try:
+                    args_list = list(args)
+                    args_list[1] = url
+                    args_new = tuple(args_list)
+                except Exception:
+                    kwargs['url'] = url
             else:
                 logger.debug('请设置正确的base_url')
                 sys.exit()
@@ -41,28 +47,24 @@ def request(func):
         logger.debug("[method]: {m}      [url]: {u} \n".format(m=func_name.upper(), u=url))
         auth = kwargs.get("auth", "")
 
-        # 处理请求头
-        headers = conf.get_item('common', 'headers')  # 从配置文件拿到登录用户请求头
-        # 如果login=False，从请求头中删掉登录态相关的键值对
+        # 根据login标记获取登录用户或游客的请求头
         login_status = kwargs.get('login', True)
-        if not login_status:
-            login_key = conf.get_item('api', 'login_key')
-            for key in login_key:
-                headers.pop(key)
+        if login_status:
+            tmp_headers: dict = conf.get_item('common', 'login_headers')
+        else:
+            tmp_headers: dict = conf.get_item('common', 'visit_headers')
         # 把上层请求方法的headers参数更新到headers里面
-        headers.update(kwargs.pop("headers", {}))
-        kwargs['headers'] = headers
+        if tmp_headers:
+            tmp_headers.update(kwargs.pop('headers', {}))
+            kwargs['headers'] = tmp_headers
 
-        # 设置请求超时时间为5s
-        try:
-            timeout_default = int(conf.get_item('common', 'timeout'))
-        except:
-            timeout_default = 10
+        # 设置请求超时时间为10s
+        timeout = conf.get_item('common', 'timeout')
         timeout_set = kwargs.pop("timeout", None)
         if timeout_set is not None:
             kwargs['timeout'] = timeout_set
         else:
-            kwargs['timeout'] = timeout_default
+            kwargs['timeout'] = int(timeout)
 
         cookies = kwargs.get("cookies", "")
         params = kwargs.get("params", "")
@@ -74,26 +76,26 @@ def request(func):
         if desc is None:
             desc = f'请求 {path} 接口'
         with allure.step(desc):
-            r = func(*args, **kwargs)
+            r = func(*args_new, **kwargs)
 
         if auth != "":
-            logger.debug(f"[auth]:\n {json_util.dumps(auth)} \n")
-        logger.debug(f"[headers]:\n {r.request.headers} \n")
+            logger.debug(f"[auth]:\n {json_util.dumps(auth, ensure_ascii=False)} \n")
+        logger.debug(f"[headers]:\n {json_util.dumps(dict(r.request.headers), ensure_ascii=False)} \n")
         if cookies != "":
-            logger.debug(f"[cookies]:\n {json_util.dumps(cookies)} \n")
+            logger.debug(f"[cookies]:\n {json_util.dumps(cookies, ensure_ascii=False)} \n")
         if params != "":
-            logger.debug(f"[params]:\n json: {json_util.dumps(params)} \n python: {params}")
+            logger.debug(f"[params]:\n {json_util.dumps(params, ensure_ascii=False)} \n")
         if data != "":
-            logger.debug(f"[data]:\n json: {json_util.dumps(data)} \n python: {data}")
+            logger.debug(f"[data]:\n {json_util.dumps(data, ensure_ascii=False)} \n")
         if json != "":
-            logger.debug(f"[json]:\n json: {json_util.dumps(json)} \n python: {json}")
+            logger.debug(f"[json]:\n {json_util.dumps(json, ensure_ascii=False)} \n")
 
         ResponseResult.status_code = r.status_code
         logger.info("-------------- Response ----------------")
         try:
             resp = r.json()
             logger.debug(f"[type]: json \n")
-            logger.debug(f"[response]:\n {resp} \n")
+            logger.debug(f"[response]:\n {json_util.dumps(resp, ensure_ascii=False)} \n")
             ResponseResult.response = resp
         except BaseException as msg:
             # 非json响应数据，最多打印100个字符
@@ -103,7 +105,7 @@ def request(func):
                 ResponseResult.response = r.content
             else:
                 logger.debug("[type]: text \n")
-                logger.debug(f"[response]:\n {r.text[:100]} \n")
+                logger.debug(f"[response]:\n {r.text} \n")
                 ResponseResult.response = r.text
 
     return wrapper
@@ -118,49 +120,49 @@ class HttpRequest(object):
 
     @request
     def get(self, url, params=None, login=True, **kwargs):
-        if "http" not in url:
-            base_url = conf.get_item('common', 'base_url')
-            if 'http' in base_url:
-                url = parse.urljoin(base_url, url)
-            else:
-                logger.debug('请设置正确的base_url')
-                sys.exit()
+        # if "http" not in url:
+        #     base_url = conf.get_item('common', 'base_url')
+        #     if 'http' in base_url:
+        #         url = parse.urljoin(base_url, url)
+        #     else:
+        #         logger.debug('请设置正确的base_url')
+        #         sys.exit()
         return requests.get(url, params=params, **kwargs)
 
     @request
     def post(self, url, data=None, json=None, login=True, **kwargs):
-        if "http" not in url:
-            base_url = conf.get_item('common', 'base_url')
-            logger.debug(base_url)
-            if 'http' in base_url:
-                url = parse.urljoin(base_url, url)
-            else:
-                logger.debug('请设置正确的base_url')
-                sys.exit()
+        # if "http" not in url:
+        #     base_url = conf.get_item('common', 'base_url')
+        #     logger.debug(base_url)
+        #     if 'http' in base_url:
+        #         url = parse.urljoin(base_url, url)
+        #     else:
+        #         logger.debug('请设置正确的base_url')
+        #         sys.exit()
         return requests.post(url, data=data, json=json, **kwargs)
 
     @request
     def put(self, url, data=None, json=None, login=True, **kwargs):
-        if "http" not in url:
-            base_url = conf.get_item('common', 'base_url')
-            if 'http' in base_url:
-                url = parse.urljoin(base_url, url)
-            else:
-                logger.debug('请设置正确的base_url')
-                sys.exit()
+        # if "http" not in url:
+        #     base_url = conf.get_item('common', 'base_url')
+        #     if 'http' in base_url:
+        #         url = parse.urljoin(base_url, url)
+        #     else:
+        #         logger.debug('请设置正确的base_url')
+        #         sys.exit()
         if json is not None:
             data = json_util.dumps(json)
         return requests.put(url, data=data, **kwargs)
 
     @request
     def delete(self, url, login=True, **kwargs):
-        if "http" not in url:
-            base_url = conf.get_item('common', 'base_url')
-            if 'http' in base_url:
-                url = parse.urljoin(base_url, url)
-            else:
-                logger.debug('请设置正确的base_url')
-                sys.exit()
+        # if "http" not in url:
+        #     base_url = conf.get_item('common', 'base_url')
+        #     if 'http' in base_url:
+        #         url = parse.urljoin(base_url, url)
+        #     else:
+        #         logger.debug('请设置正确的base_url')
+        #         sys.exit()
         return requests.delete(url, **kwargs)
 
     @property
