@@ -63,6 +63,7 @@ class IosDriver(object):
         return IosDriver._instance[serial_no]
 
     def install_app(self, ipa_url):
+        """安装应用"""
         cmd = f'tidevice -u {self.serial_no} install {ipa_url}'
         logger.info(f'安装应用: {ipa_url}')
         output = subprocess.getoutput(cmd)
@@ -73,6 +74,7 @@ class IosDriver(object):
             logger.info(f'{self.serial_no} 安装应用{ipa_url}失败，因为{output}')
 
     def new_install_app(self, ipa_url, bundle_id=None):
+        """先卸载，再安装"""
         pkg_name = bundle_id if bundle_id else self.bundle_id
         self.uninstall_app(pkg_name)
         cmd = f'tidevice -u {self.serial_no} install {ipa_url}'
@@ -85,6 +87,7 @@ class IosDriver(object):
             logger.info(f'{self.serial_no} 安装应用{ipa_url}失败，因为{output}')
 
     def uninstall_app(self, bundle_id=None):
+        """卸载应用"""
         pkg_name = bundle_id if bundle_id else self.bundle_id
         cmd = f'tidevice -u {self.serial_no} uninstall {pkg_name}'
         logger.info(f'卸载应用: {pkg_name}')
@@ -96,12 +99,14 @@ class IosDriver(object):
             logger.info(f'{self.serial_no} 卸载应用{pkg_name}失败，因为{output}')
 
     def start_app(self, bundle_id=None):
+        """启动应用"""
         if not bundle_id:
             bundle_id = self.bundle_id
         logger.info(f'启动应用: {bundle_id}')
         self.d.app_start(bundle_id)
 
     def force_start_app(self, bundle_id=None):
+        """重启应用"""
         if not bundle_id:
             bundle_id = self.bundle_id
         logger.info(f'强制启动应用: {bundle_id}')
@@ -109,32 +114,38 @@ class IosDriver(object):
         self.start_app(bundle_id)
 
     def stop_app(self, bundle_id=None):
+        """停止应用"""
         if not bundle_id:
             bundle_id = self.bundle_id
         logger.info(f'停止应用: {bundle_id}')
         self.d.app_terminate(bundle_id)
 
     def app_current(self):
+        """获取运行中的app列表"""
         cur_apps = self.d.app_current()
         logger.info(f'获取运行中的app列表: {cur_apps}')
         return cur_apps
 
     def app_launch(self, bundle_id=None):
+        """将应用切到前台"""
         if not bundle_id:
             bundle_id = self.bundle_id
         logger.info(f'将应用切到前台: {bundle_id}')
         self.d.app_launch(bundle_id)
 
     def back(self):
+        """返回上一页"""
         logger.info('返回上一页')
         time.sleep(1)
         self.d.swipe(0, 100, 100, 100)
 
     def go_home(self):
+        """返回手机主页"""
         logger.info('返回手机主页')
         self.d.home()
 
     def send_keys(self, value):
+        """输入内容"""
         logger.info(f'输入: {value}')
         self.d.send_keys(value)
 
@@ -187,16 +198,19 @@ class IosDriver(object):
 
     @property
     def page_content(self):
+        """获取页面xml内容"""
         page_source = self.d.source(accessible=False)
         logger.info(f'获取页面内容: \n{page_source}')
         return page_source
 
     def get_window_size(self):
+        """获取屏幕尺寸"""
         size = self.d.window_size()
         logger.info(f'获取屏幕尺寸: {size}')
         return size
 
     def click(self, x, y):
+        """点击坐标"""
         logger.info(f'点击坐标: ({x}, {y})')
         logger.info(f'{self.serial_no} Tap point ({x}, {y})')
         self.d.appium_settings({"snapshotMaxDepth": 0})
@@ -205,20 +219,24 @@ class IosDriver(object):
         time.sleep(1)
 
     def double_click(self, x, y):
+        """双击坐标"""
         logger.info(f'双击坐标: {x},{y}')
         self.d.double_tap(x, y)
 
     def tap_hold(self, x, y):
+        """长按坐标"""
         logger.info(f'长按: {x},{y}')
         self.d.tap_hold(x, y, 1.0)
 
     def click_alert(self, alert_list: list):
+        """点击弹窗"""
         try:
             self.d.alert.click(alert_list)
         except:
             pass
 
     def swipe(self, start_x, start_y, end_x, end_y, duration=0):
+        """根据坐标滑动"""
         logger.info(f'从坐标({start_x}, {start_y})滑动到({end_x}, {end_y})')
         logger.info(f'{self.serial_no} swipe from point ({start_x}, {start_y}) to ({end_x}, {end_y})')
         self.d.appium_settings({"snapshotMaxDepth": 2})
@@ -227,6 +245,7 @@ class IosDriver(object):
         time.sleep(2)
 
     def swipe_by_screen_percent(self, start_x_percent, start_y_percent, end_x_percent, end_y_percent, duration=0):
+        """根据屏幕百分比滑动"""
         logger.info(f'根据屏幕百分比进行滑动')
         w, h = self.d.window_size()
         start_x = w * start_x_percent
@@ -236,40 +255,48 @@ class IosDriver(object):
         self.swipe(start_x, start_y, end_x, end_y, duration=duration)
 
     def swipe_left(self, start_percent=1, end_percent=0.5):
+        """往左滑动"""
         logger.info('往左边滑动')
         w, h = self.d.window_size()
         self.swipe(start_percent * (w - 1), h/2, end_percent * w, h/2)
 
     def swipe_right(self, start_percent=0.5, end_percent=1):
+        """往右滑动"""
         logger.info('往右边滑动')
         w, h = self.d.window_size()
         self.swipe(start_percent * w, h / 2, end_percent * (w - 1), h / 2)
 
     def swipe_up(self, start_percent=0.8, end_percent=0.2):
+        """往上滑动"""
         logger.info('往上边滑动')
         w, h = self.d.window_size()
         self.swipe(w / 2, start_percent * h, w / 2, end_percent * h)
 
     def swipe_down(self, start_percent=0.2, end_percent=0.8):
+        """往下滑动"""
         logger.info('往下面滑动')
         w, h = self.d.window_size()
         self.swipe(w / 2, start_percent * h, w / 2, end_percent * h)
 
     def check(self):
+        """检查设备连接状态"""
         logger.info('健康检查')
         self.d.healthcheck()
 
     def locked(self):
+        """检查手机是否锁屏"""
         logger.info('是否锁屏')
         status = self.d.locked()
         logger.info(status)
         return status
 
     def lock(self):
+        """锁屏"""
         logger.info('锁住屏幕')
         self.d.lock()
 
     def unlock(self):
+        """解锁"""
         logger.info('解锁屏幕')
         self.d.unlock()
 
@@ -284,18 +311,21 @@ class IosDriver(object):
 
     @property
     def battery_info(self):
+        """电池信息"""
         info = self.d.battery_info()
         logger.info(f'电池信息: {info}')
         return info
 
     @property
     def device_info(self):
+        """设备信息"""
         info = self.d.device_info()
         logger.info(f'设备信息: {info}')
         return info
 
     @property
     def scale(self):
+        """获取分辨率"""
         scale = self.d.scale
         logger.info(f'设备分辨率: {scale}')
         return scale
