@@ -16,7 +16,7 @@ class IosElement(object):
                  label=None,
                  value=None,
                  text=None,
-                 cname=None,
+                 class_name=None,
                  xpath=None,
                  index=None,
                  desc=None):
@@ -40,8 +40,8 @@ class IosElement(object):
             kwargs['value'] = value
         if text is not None:
             kwargs['text'] = text
-        if cname is not None:
-            kwargs['className'] = cname
+        if class_name is not None:
+            kwargs['className'] = class_name
         self._xpath = xpath
         self._index = index if index is not None else 0
         self.desc = desc
@@ -153,56 +153,67 @@ class IosElement(object):
 
     @property
     def info(self):
+        """获取元素信息"""
         logger.info(f'获取元素: {self._kwargs} 的所有属性')
         return self.get_element().info
 
     @property
     def text(self):
+        """获取元素文本"""
         logger.info(f'获取元素: {self._kwargs} 的text属性')
         return self.get_element().text
 
     @property
     def className(self):
+        """获取元素className"""
         logger.info(f'获取元素: {self._kwargs} 的className属性')
         return self.get_element().className
 
     @property
     def name(self):
+        """获取元素name"""
         logger.info(f'获取元素: {self._kwargs} 的name属性')
         return self.get_element().name
 
     @property
     def visible(self):
+        """获取元素visible属性"""
         logger.info(f'获取元素: {self._kwargs} 的visible属性')
         return self.get_element().visible
 
     @property
     def value(self):
+        """获取元素value"""
         logger.info(f'获取元素: {self._kwargs} 的value属性')
         return self.get_element().value
 
     @property
     def label(self):
+        """获取元素label"""
         logger.info(f'获取元素: {self._kwargs} 的label属性')
         return self.get_element().label
 
     @property
     def enabled(self):
+        """获取元素enabled属性"""
         logger.info(f'获取元素: {self._kwargs} 的enabled属性')
         return self.get_element().enabled
 
     @property
     def displayed(self):
+        """获取元素displayed属性"""
         logger.info(f'获取元素: {self._kwargs} 的displayed属性')
         return self.get_element().displayed
 
     @property
     def bounds(self):
+        """获取元素bounds属性"""
         logger.info(f'获取元素: {self._kwargs} 的bounds属性')
         return self.get_element().bounds
 
     @property
     def rect(self):
+        """获取元素左上角坐标和宽高"""
         logger.info(f'获取元素: {self._kwargs} 的左上角坐标和宽高')
         return [item * self._d.scale for item in list(self.get_element().bounds)]
 
@@ -220,6 +231,7 @@ class IosElement(object):
         return True
 
     def wait_gone(self, timeout=10):
+        """等待元素消失"""
         logger.info(f'等待元素{self._kwargs}消失')
         flag = self.get_element().wait_gone(timeout=timeout)
         logger.info(flag)
@@ -227,6 +239,7 @@ class IosElement(object):
 
     def click(self, retry=3, timeout=3, alert_list=None):
         """
+        单击
         @param: retry，重试次数
         @param: timeout，每次重试超时时间
         @param: alert_list，异常弹窗列表
@@ -239,15 +252,18 @@ class IosElement(object):
     #     self.get_element(retry=0, timeout=1).click()
 
     def click_exists(self, timeout=3):
+        """元素存在时点击"""
         logger.info(f'存在才点击元素: {self._kwargs},{self._index}')
         if self.exists(timeout=timeout):
             self.click()
 
     def clear_text(self):
+        """清除文本"""
         logger.info('清除文本: {text}')
         self.get_element().clear_text()
 
     def set_text(self, text):
+        """输入内容"""
         logger.info(f'输入框 {self._kwargs},{self._index} 输入: {text}')
         self.get_element().set_text(text)
 
@@ -263,19 +279,23 @@ class IosElement(object):
             self.get_element().scroll()
 
     def swipe_left(self):
+        """往左滑动"""
         self.get_element().swipe("left")
 
     def swipe_right(self):
+        """往右滑动"""
         self.get_element().swipe("right")
 
     def swipe_up(self):
+        """往上滑动"""
         self.get_element().swipe("up")
 
     def swipe_down(self):
+        """往下滑动"""
         self.get_element().swipe("down")
 
     def child(self, *args, **kwargs):
-        """不能用于PageObject，会导致在应用启动前进行元素识别"""
+        """获取兄弟节点，不能用于PageObject，会导致在应用启动前进行元素识别"""
         return self.get_element().child(*args, **kwargs)
 
 
