@@ -72,8 +72,7 @@ class Browser(object):
             exe_path = 'chromedriver'
             logger.debug(f'在环境变量中搜索驱动文件: {exe_path}')
             driver = webdriver.Chrome(options=chrome_options,
-                                      executable_path=exe_path,
-                                      )
+                                      executable_path=exe_path)
         except Exception as first_e:
             logger.debug(f'找不到执行文件: {exe_path}')
             logger.debug(first_e)
@@ -81,8 +80,7 @@ class Browser(object):
                 exe_path = conf.get_item('common', 'executable_path')
                 logger.debug(f'在指定目录中搜索驱动文件: {exe_path}')
                 driver = webdriver.Chrome(options=chrome_options,
-                                          executable_path=exe_path,
-                                          )
+                                          executable_path=exe_path)
             except Exception as second_e:
                 logger.debug(f'找不到执行文件: {exe_path}')
                 logger.debug(second_e)
@@ -90,8 +88,7 @@ class Browser(object):
                     logger.debug(f'在淘宝镜像中搜索驱动文件: ')
                     exe_path = ChromeDriverManager().install()
                     driver = webdriver.Chrome(options=chrome_options,
-                                              executable_path=exe_path,
-                                              )
+                                              executable_path=exe_path)
                 except Exception as third_e:
                     logger.debug(f'找不到执行文件: {exe_path}')
                     logger.debug(third_e)
