@@ -1,3 +1,4 @@
+import sys
 import time
 from qrunner.utils.log import logger
 from qrunner import AndroidDriver, IosDriver, WebDriver, H5Driver
@@ -5,6 +6,7 @@ from typing import Union
 
 
 class Page(object):
+    url = None
 
     def __init__(self, driver: Union[AndroidDriver, IosDriver, WebDriver, H5Driver]):
         self.driver = driver
@@ -14,4 +16,12 @@ class Page(object):
         logger.info(f'休眠 {n} 秒')
         time.sleep(n)
 
+    def open(self):
+        try:
+            self.driver.open_url(self.url)
+        except Exception as e:
+            logger.error(f'请设置页面url: {str(e)}')
+            sys.exit()
+
+
 
