@@ -1,5 +1,4 @@
 import os
-import json
 import yaml
 
 
@@ -30,10 +29,7 @@ conf = Config()
 
 if __name__ == '__main__':
     conf.get_all()
-    conf.set_item('common', 'platform', 'android')
-    conf.set_item('common', 'platform', 'ios')
-    print(conf.get_item('app', 'android_alert'))
-    print(conf.get_item('common', 'platform'))
+
 
 
 
